#!/bin/sh

#
# Version = VERSION in /etc/vdr/plugins/mylinvdr.conf
#
# Erstellt eine Sicherungskopie basierend auf den Original-Daten von LinVDR 0.7 und
# der auf dem PC installierten Updates, nderungen, etc. Das fertige Archiv wird dann
# in ein DVD-ISO umgewandelt und anschlieend auf DVD+R(W) gebrannt. Diese DVD kann
# anschlieend wie die Original LinVDR 0.7 Boot-ISO zur Installation benutzt werden und
# richtet das gesamte System wieder so ein wie zuvor. Nur Daten, welche in der Datei
# /etc/vdr/plugins/mylinvdr.conf mit exclude angegeben sind, werden nicht gesichert, um z.B.
# die eigenen Videos und MP3s, etc auszunehmen.
#
# Skript erstellt Dank Hilfe von vielen aus dem www.vdr-portal.de Forum u.a. von viper67,
# 44892 (Sascha Theissen), decembersoul, Mahlzeit und manni
#
# Bei Weiterentwicklungen wird um Zusendung einer Kopie gebeten an linvdr@theissen-legal.com
#
# Viel Spa mit dem Skript!
#

# Funktionendefinition
function message
{
	case "$2" in
  		vdr)
  			/usr/bin/svdrpsend.pl mesg "$1"
  			sleep $3
  			;;
  		shell)
  			echo "$1"
  			;;
  		file)
  			echo "$1" > $LOGFILE
  			;;
	esac
}


# Prft ob ein Parameter angegeben wurde, falls kein Parameter da ist wird automatisch ISO erstellt
# und gebrannt, das ISO wird danach gelscht.
if [ -z $1 ]
then
	# Kein Parameter da, es wird auf jeden Fall gebrannt und das ISO nach dem Brennen gelscht
	TOBURN=1
	DELETE=1
	OUTPUT=vdr
	echo "$LANG_SWITCH_BURN_DEFAULT"
else
	# Es wurde ein Parameter angegeben, Auswertung was gemacht werden soll.
	case "$1" in 
		iso)
			TOBURN=0
			DELETE=0
			echo "$LANG_SWITCH_ISO"
			;;
		burn)
			TOBURN=1
			DELETE=0
			echo "$LANG_SWITCH_BURN"
			;;
		burndel)
			TOBURN=1
			DELETE=1
			echo "$LANG_SWITCH_BURNDEL"
			;;
		help|*)
			echo ""
			echo "MyLinVDR, Version $VERSION"
			echo ""
			echo "$0 {iso|burn|burndel}"
			echo "$LANG_HELP_ISO"
			echo "$LANG_HELP_BURN"
			echo "$LANG_HELP_BURNDEL"
			echo ""
			exit 0
			;;
	esac
fi

if [ -z "$2" ]
then
	OUTPUT=vdr
else
	case "$2" in
		vdr)
			OUTPUT=vdr
			;;
		shell)
			OUTPUT=shell
			;;
		file)
			OUTPUT=file
			;;
		*)
			echo " {vdr|shell|file}"
			;;
	esac
fi

# laden der Einstellungen aus /etc/vdr/plugins/mylinvdr.conf
if [ -e /etc/vdr/plugins/mylinvdr.conf ]
then
	. /etc/vdr/plugins/mylinvdr.conf
else
	message "/etc/vdr/plugins/mylinvdr.conf nicht gefunden. Bearbeitung abgebrochen" $OUTPUT 3
	exit 1
fi

# laden der Sprach-Datei // loading language file
if [ -z $LANGUAGE ]
then
	# Default Language, sonst gibt es Fehler wenn die passende Datei nicht gefunden werden kann
	LANGUAGE=de_DE
fi
if [ -e /etc/vdr/plugins/mylinvdr/$LANGUAGE.lang ]
then
	. /etc/vdr/plugins/mylinvdr/$LANGUAGE.lang
else
	message "/etc/vdr/plugins/mylinvdr/$LANGUAGE.lang nicht gefunden. Bearbeitung abgebrochen" $OUTPUT 3
	exit 1
fi


message "$LANG_OUTPUT_ISO_CREATE" $OUTPUT $SLEEPTIME

# Prueft, ob $BOOTISO schon existiert, falls nicht, werden die Daten von der Original- LinVDR-CD
# angefordert, das Verzeichnis erstellt und die Daten kopiert, danach das Skript weiter abgearbeitet
if [ ! -e $BOOTISO ]
then
	# Dateien kopieren erforderlich
	mkdir $BOOTISO
	message "$LANG_OUTPUT_NEED_ORIG_CD" $OUTPUT $SLEEPTIME
	read
	mount /mnt/dvd
	cp -ar /mnt/dvd/isolinux $BOOTISO
	cp -ar /mnt/dvd/LinVDR $BOOTISO
	eject /mnt/dvd
	message "$LANG_OUTPUT_CHANGE_DISC" $OUTPUT $SLEEPTIME
	read
	cp /etc/vdr/plugins/mylinvdr.message.txt $BOOTISO/isolinux
fi

if [ -e $BOOTISO/LinVDR/linvdr-0.7.tar.gz ]
then
	rm $BOOTISO/LinVDR/linvdr-0.7.tar.gz
fi

# Baue die Excludeliste aus den beiden Konfigurationsparametern zusammen
for dir in $EXCLUDEDIRS
do
	EXCLUDE="$EXCLUDE --exclude=$dir"
done
for file in $EXCLUDEFILES
do
	EXCLUDE="$EXCLUDE --exclude=$file"
done

# Erstellen des gezippten Tar-Archivs mit aktuellen Daten.
# Ausgenommen Dateien und Verzeichnisse aus EXCLUDEDIRS und EXCLUDEFILES
ERRMSG="$LANG_TAR_ERROR"
TAR="tar czvplf $BOOTISO/LinVDR/linvdr-0.7.tar.gz $EXCLUDE $INCLUDEDIRS $INCLUDEFILES"
eval $TAR >$LOGFILE 2>$ERRLOGFILE
 
#Pruefung ob bei tar-Aufruf alles in Ordnung war, andernfalls Fehlerausgabe
if [ $? -eq 0 ]
then
	# ISO-File erstellen
	message "$LANG_OUTPUT_CREATE_IMAGE" $OUTPUT $SLEEPTIME
	ERRMSG="$LANG_ERROR_ISO"
	mkisofs -o $ISOPATH/$ISOFILE -b isolinux/isolinux.bin -no-emul-boot -boot-load-size 4 -boot-info-table -joliet-long -RJ -r $BOOTISO/
else
	message "$ERRMSG" $OUTPUT $SLEEPTIME
	exit 1
fi

# Pruefen ob beim mkisofs alles in Ordnung war, ansonsten Fehlerausgabe
if [ $? -eq 0 ]
then
	if [ "x$TOBURN" == "x1" ]
	then
		# Wenn das Image gebrannt werden soll
		message "$LANG_OUTPUT_ISO_BURN" $OUTPUT $SLEEPTIME
		ERRMSG="$LANG_ERROR_FORMAT_RW"
		dvd+rw-format -force /dev/burner
		if [ $? -eq 0 ]
		then
			ERRMSG="$LANG_ERROR_BURN_DVD"
			growisofs -dvd-compat -use-the-force-luke=tty -Z /dev/burner=$ISOPATH/$ISOFILE
			if [ $? -eq 0 ]
			then
				eject /dev/burner
				message "$LANG_SUCCESS" $OUTPUT $SLEEPTIME
				if [ "x$DELETE" == "x1" ]
				then
					ERRMSG="$LANG_ERROR_DELETE_ISO"
					rm $ISOPATH/$ISOFILE
					if [ $? -eq 0 ]
					then
						message "$LANG_ISO_DELETED" $OUTPUT $SLEEPTIME
					else
						message "$ERRMSG" $OUTPUT $SLEEPTIME
						exit 1
					fi
				fi
			else
				message "$ERRMSG" $OUTPUT $SLEEPTIME
				exit 1
			fi
		else
			message "$ERRMSG" $OUTPUT $SLEEPTIME
			exit 1
		fi
	else
		message "$LANG_ISO_CREATED_DIR" $OUTPUT $SLEEPTIME
		exit 0
	fi
else
	message "$ERRMSG" $OUTPUT $SLEEPTIME
	exit 1
fi

